@@ -4,9 +4,8 @@ Display any array, webcam, or video file.
 display is a function that displays these in their own windows.
 """
 
-__version__ = "0.7.2"
+__version__ = "0.7.3"
 
-from .window.subscriber_windows import display, breakpoint_display
-from .frame.frame_updater import read_updates
+from .window.subscriber_windows import display, breakpoint_display, read_updates
 from .frame.frame_publishing import publish_updates_zero_mq, publish_updates_ros
 from . import effects
