@@ -26,7 +26,7 @@ class FrameUpdater(threading.Thread):
         callbacks: Optional[Union[List[FrameCallable], FrameCallable]] = None,
         request_size: Tuple[int, int] = (-1, -1),
         high_speed: bool = True,
-        fps_limit: float = 240,
+        fps_limit: float = float("inf"),
     ):
         """Create the frame updater thread."""
         super(FrameUpdater, self).__init__(target=self.loop, args=())
@@ -115,7 +115,7 @@ class FrameUpdater(threading.Thread):
             raise self.exception_raised
 
 
-async def read_updates(
+'''async def read_updates(
     *vids,
     callbacks: Optional[
         Union[
@@ -132,14 +132,14 @@ async def read_updates(
     """
     Read back all updates from the requested videos.
 
-    Example usage:
+    Examp#le usage:
 
-    .. code-block:: python
+    .. co#de-block:: python
 
-      >>> from examples.videos import test_video
-      >>> f = 0
-      >>> for f, r in enumerate(read_updates(test_video, end_callback=lambda :f==2)):
-      ...   print(f"Frame:{f}. Array:{r}")
+      >>#> from examples.videos import test_video
+      >>#> f = 0
+      >>#> for f, r in enumerate(read_updates(test_video, end_callback=lambda :f==2)):
+      ..#.   print(f"Frame:{f}. Array:{r}")
 
     """
     from displayarray.window import SubscriberWindows
@@ -174,7 +174,7 @@ async def read_updates(
     for v in vid_names:
         subscriber_dictionary.stop_cam(v)
     for v in vid_threads:
-        v.join()
+        v.join()'''
 
 
 async def read_updates_zero_mq(
